@@ -1,4 +1,4 @@
-// Copyright 2021 Northern.tech AS
+// Copyright 2023 Northern.tech AS
 //
 //    Licensed under the Apache License, Version 2.0 (the "License");
 //    you may not use this file except in compliance with the License.
@@ -36,7 +36,7 @@ func (c *CompressorGzip) NewReader(r io.Reader) (io.ReadCloser, error) {
 }
 
 func (c *CompressorGzip) NewWriter(w io.Writer) (io.WriteCloser, error) {
-	return gzip.NewWriter(w), nil
+	return gzip.NewWriterLevel(w, gzip.BestCompression)
 }
 
 func init() {
