@@ -1,4 +1,4 @@
-// Copyright 2021 Northern.tech AS
+// Copyright 2023 Northern.tech AS
 //
 //    Licensed under the Apache License, Version 2.0 (the "License");
 //    you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ import (
 	"crypto/rand"
 	"crypto/rsa"
 	"crypto/x509"
+	"encoding/asn1"
 	"encoding/base64"
 	"encoding/pem"
 	"math/big"
@@ -45,9 +46,7 @@ type Crypto interface {
 	Verify(message, sig []byte, key interface{}) error
 }
 
-//
 // RSA Crypto interface implementation
-//
 type RSA struct{}
 
 func (r *RSA) Sign(message []byte, key interface{}) ([]byte, error) {
@@ -76,11 +75,11 @@ func (r *RSA) Verify(message, sig []byte, key interface{}) error {
 	return rsa.VerifyPKCS1v15(rsaKey, crypto.SHA256, h[:], sig)
 }
 
-//
 // ECDSA Crypto interface implementation
-//
 const ecdsa256curveBits = 256
 const ecdsa256keySize = 32
+const ecdsa256Asn1SizeBytes = 70
+const ecdsa256Asn1Padding = 2
 
 type ECDSA256 struct{}
 
@@ -162,11 +161,56 @@ func MarshalECDSASignature(r, s *big.Int) ([]byte, error) {
 }
 
 func UnmarshalECDSASignature(sig []byte) (r, s *big.Int, e error) {
-	// check if the size of the key matches provided one
-	if len(sig) != 2*ecdsa256keySize {
-		return nil, nil, errors.Errorf("signer: invalid ecdsa key size: %d", len(sig))
+	// if the length of the signature is the double of key size, we know (and assume)
+	// that it was us who created it via MarshalECDSASignature.
+	// After the introduction of the hardware security support there is another possibility
+	// (see below)
+	if len(sig) == 2*ecdsa256keySize {
+		return UnmarshalECDSASignatureMenderArtifact(sig)
 	}
 
+	// in case of a key supplied via PKCS#11 URI, we have no control over what the signature is
+	// since it is designed to be actually verified via the same mechanism (PKCS#11 URI).
+	// We know here that it is ECDSA key, and judging form the size we can assume
+	// that it is ASN.1 encoded. If so, then it should be between 70 and 72 bytes.
+	// In other words:
+	// if the signature has not been created with MarshalECDSASignature, then we assume
+	// it is to be decoded via ASN.1, with the protection on the signature length.
+	if len(sig) >= ecdsa256Asn1SizeBytes &&
+		len(sig) <= ecdsa256Asn1SizeBytes+ecdsa256Asn1Padding {
+		return UnmarshalECDSASignatureASN1(sig)
+	}
+	return nil, nil, errors.Errorf("signer: invalid signature length: %d. "+
+		"For ECDSA only P-256 is supported.", len(sig))
+}
+
+func UnmarshalECDSASignatureASN1(sig []byte) (r *big.Int, s *big.Int, err error) {
+	var value asn1.RawValue
+	_, err = asn1.Unmarshal(sig, &value)
+	if err != nil {
+		return nil, nil, errors.Wrap(err, "cannot unmarshal asn1 data")
+	}
+	bytesValue := value.Bytes
+	if len(bytesValue) > 0 {
+		var v asn1.RawValue
+		bytesValue, err = asn1.Unmarshal(bytesValue, &v)
+		if err != nil {
+			return nil, nil, errors.Wrap(err, "cannot unmarshal asn1 r value")
+		}
+		r = big.NewInt(0).SetBytes(v.Bytes)
+	}
+	if len(bytesValue) > 0 {
+		var v asn1.RawValue
+		_, err = asn1.Unmarshal(bytesValue, &v)
+		if err != nil {
+			return nil, nil, errors.Wrap(err, "cannot unmarshal asn1 s value")
+		}
+		s = big.NewInt(0).SetBytes(v.Bytes)
+	}
+	return r, s, nil
+}
+
+func UnmarshalECDSASignatureMenderArtifact(sig []byte) (r *big.Int, s *big.Int, err error) {
 	// get the signature; see corresponding `Sign` function for more details
 	// about serialization
 	r = big.NewInt(0).SetBytes(sig[:ecdsa256keySize])
@@ -284,6 +328,7 @@ func GetKeyAndSignMethod(keyPEM []byte) (*SigningMethod, error) {
 	if block == nil {
 		return nil, errors.New("signer: failed to parse private key")
 	}
+
 	rsaKey, err := x509.ParsePKCS1PrivateKey(block.Bytes)
 	if err == nil {
 		pub, keyErr := x509.MarshalPKIXPublicKey(rsaKey.Public())
@@ -292,6 +337,7 @@ func GetKeyAndSignMethod(keyPEM []byte) (*SigningMethod, error) {
 		}
 		return &SigningMethod{Key: rsaKey, Public: pub, Method: new(RSA)}, nil
 	}
+
 	ecdsaKey, err := x509.ParseECPrivateKey(block.Bytes)
 	if err == nil {
 		pub, keyErr := x509.MarshalPKIXPublicKey(ecdsaKey.Public())
@@ -300,5 +346,31 @@ func GetKeyAndSignMethod(keyPEM []byte) (*SigningMethod, error) {
 		}
 		return &SigningMethod{Key: ecdsaKey, Public: pub, Method: new(ECDSA256)}, nil
 	}
-	return nil, errors.Wrap(err, "signer: unsupported private key type or error occured")
+
+	key, err := x509.ParsePKCS8PrivateKey(block.Bytes)
+	if ecdsaKey, ok := key.(*ecdsa.PrivateKey); ok {
+		if err == nil {
+			pub, keyErr := x509.MarshalPKIXPublicKey(ecdsaKey.Public())
+			if keyErr != nil {
+				return nil, errors.Wrap(err, "signer: can not extract public ECDSA key")
+			}
+			return &SigningMethod{Key: ecdsaKey, Public: pub, Method: new(ECDSA256)}, nil
+		}
+	}
+
+	if rsaKey, ok := key.(*rsa.PrivateKey); ok {
+		if err == nil {
+			pub, keyErr := x509.MarshalPKIXPublicKey(rsaKey.Public())
+			if keyErr != nil {
+				return nil, errors.Wrap(err, "signer: can not extract public RSA key")
+			}
+			return &SigningMethod{Key: rsaKey, Public: pub, Method: new(RSA)}, nil
+		}
+	}
+
+	if err == nil {
+		err = errors.New("unsupported private key type")
+	}
+
+	return nil, errors.Wrap(err, "signer: unsupported private key type or error occurred")
 }
