@@ -34,7 +34,7 @@ XwaUNml5EhW79AdibBXZiZt8fMhCjUd/4ce3rLNjnbIn1o9L6pzV4CcVJ8+iNhne
 MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDSTLzZ9hQq3yBB+dMDVbKem6ia
 v1J6opg6DICKkQ4M/yhlw32BCGm2ArM3VwQRgq6Q1sNSq953n5c1EO3Xcy/qTAKc
 XwaUNml5EhW79AdibBXZiZt8fMhCjUd/4ce3rLNjnbIn1o9L6pzV4CcVJ8+iNhne
-5vbA+63vRCnrc8QuYwIDAQAC
+5vbA+63vRCnrc8QuYwIDAQAD
 -----END PUBLIC KEY-----`
 	PublicRSAKeyInvalid = `-----BEGIN PUBLIC KEY-----
 MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDSTLzZ9hQq3yBB+dMDVbKem6ia
@@ -259,5 +259,10 @@ func TestECDSARaw(t *testing.T) {
 	// use wrong size key for verification
 	err = r.Verify([]byte("my message"), []byte("signature"), crypt.Key)
 	assert.Error(t, err)
-	assert.Contains(t, errors.Cause(err).Error(), "invalid ecdsa key size")
+	assert.Contains(t, errors.Cause(err).Error(), "signer: invalid signature length:")
+
+	// use wrong size key for verification
+	err = r.Verify([]byte("my message"), []byte("signature longer than the 72 bytes for 256 means that we definitely are having something we do not recognize in any way, which should happen here, ever since MEN-7523."), crypt.Key)
+	assert.Error(t, err)
+	assert.Contains(t, errors.Cause(err).Error(), "invalid signature length")
 }
