@@ -1,4 +1,4 @@
-// Copyright 2022 Northern.tech AS
+// Copyright 2023 Northern.tech AS
 //
 //    Licensed under the Apache License, Version 2.0 (the "License");
 //    you may not use this file except in compliance with the License.
@@ -53,6 +53,7 @@ const LatestFormatVersion = 3
 
 // Copied from urfave/cli/template.go
 // with the addition of the NOTE on the `global` `--compression flag`
+//
 //nolint:lll
 var menderAppHelpTemplate = `NAME:
    {{.Name}}{{if .Usage}} - {{.Usage}}{{end}}
@@ -133,6 +134,13 @@ func getCliContext() *cli.App {
 			"the Artifact.",
 	}
 
+	signserverWorkerName := cli.StringFlag{
+		Name: "keyfactor-signserver-worker",
+		Usage: "The name of the SignServer worker that will be used to sign " +
+			"the Artifact. The worker name must be associated with a Plain Signer worker " +
+			"in SignServer. ",
+	}
+
 	vaultTransitKeyFlag := cli.StringFlag{
 		Name: "vault-transit-key",
 		Usage: "Key name of the Hashicorp Vault transit key that will be used to sign " +
@@ -153,6 +161,17 @@ func getCliContext() *cli.App {
 			"the Artifact signature.",
 	}
 
+	azureKeyFlag := cli.StringFlag{
+		Name: "azure-key",
+		Usage: "Name of the Azure Key Vault key that will be used to sign the Artifact. " +
+			"This operation requires the keys/sign and keys/get permissions. Uses " +
+			"DefaultAzureCredential to authenticate, which tries to authenticate based " +
+			"on a credential chain, stopping when one provides a token. Need to set the " +
+			"KEY_VAULT_NAME environment variable for the key vault name. To use a " +
+			"specific key version, set the KEY_VAULT_KEY_VERSION environment variable. " +
+			"If not set, it will use the latest key.",
+	}
+
 	//
 	// Common Artifact flags
 	//
@@ -161,6 +180,7 @@ func getCliContext() *cli.App {
 		Usage:    "Name of the artifact",
 		Required: true,
 	}
+
 	artifactNameDepends := cli.StringSliceFlag{
 		Name:  "artifact-name-depends, N",
 		Usage: "Sets the name(s) of the artifact(s) which this update depends upon",
@@ -173,6 +193,11 @@ func getCliContext() *cli.App {
 		Name:  "depends-groups, G",
 		Usage: "The group(s) the artifact depends on",
 	}
+	artifactAddScripts := cli.StringSliceFlag{
+		Name: "script, s",
+		Usage: "Adds additional state script to an already existing artifact." +
+			"You can specify multiple scripts providing this parameter multiple times.",
+	}
 
 	// Common Software Version flags
 	softwareVersionNoDefault := cli.BoolFlag{
@@ -241,7 +266,7 @@ func getCliContext() *cli.App {
 		artifactName,
 		cli.StringFlag{
 			Name:  "output-path, o",
-			Usage: "Full path to output artifact file.",
+			Usage: "Full path to output artifact file, '-' for stdout.",
 		},
 		cli.IntFlag{
 			Name:  "version, v",
@@ -251,6 +276,8 @@ func getCliContext() *cli.App {
 		privateKeyFlag,
 		gcpKMSKeyFlag,
 		vaultTransitKeyFlag,
+		signserverWorkerName,
+		azureKeyFlag,
 		cli.StringSliceFlag{
 			Name: "script, s",
 			Usage: "Full path to the state script(s). You can specify multiple " +
@@ -327,7 +354,7 @@ func getCliContext() *cli.App {
 		},
 		cli.StringFlag{
 			Name:  "output-path, o",
-			Usage: "Full path to output artifact file.",
+			Usage: "Full path to output artifact file, '-' for stdout.",
 		},
 		cli.IntFlag{
 			Name:  "version, v",
@@ -383,6 +410,8 @@ func getCliContext() *cli.App {
 		privateKeyFlag,
 		gcpKMSKeyFlag,
 		vaultTransitKeyFlag,
+		signserverWorkerName,
+		azureKeyFlag,
 		//////////////////////
 		// Sotware versions //
 		//////////////////////
@@ -394,6 +423,10 @@ func getCliContext() *cli.App {
 		},
 		softwareVersionValue,
 		softwareFilesystem,
+		cli.BoolFlag{
+			Name:  "no-progress",
+			Usage: "Suppress the progressbar output",
+		},
 	}
 	writeModuleCommand.Before = applyCompressionInCommand
 
@@ -418,7 +451,7 @@ func getCliContext() *cli.App {
 		artifactName,
 		cli.StringFlag{
 			Name:  "output-path, o",
-			Usage: "Full path to output artifact file.",
+			Usage: "Full path to output artifact file, '-' for standard output.",
 		},
 		cli.IntFlag{
 			Name:  "version, v",
@@ -435,7 +468,9 @@ func getCliContext() *cli.App {
 		payloadDepends,
 		privateKeyFlag,
 		gcpKMSKeyFlag,
+		signserverWorkerName,
 		vaultTransitKeyFlag,
+		azureKeyFlag,
 		/////////////////////////
 		// Version 3 specifics.//
 		/////////////////////////
@@ -470,8 +505,10 @@ func getCliContext() *cli.App {
 		Flags: []cli.Flag{
 			publicKeyFlag,
 			gcpKMSKeyFlag,
+			signserverWorkerName,
 			vaultTransitKeyFlag,
 			pkcs11Flag,
+			azureKeyFlag,
 		},
 	}
 
@@ -488,8 +525,10 @@ func getCliContext() *cli.App {
 		Flags: []cli.Flag{
 			publicKeyFlag,
 			gcpKMSKeyFlag,
+			signserverWorkerName,
 			vaultTransitKeyFlag,
 			pkcs11Flag,
+			azureKeyFlag,
 			cli.BoolFlag{
 				Name:  "no-progress",
 				Usage: "Suppress the progressbar output",
@@ -512,6 +551,7 @@ func getCliContext() *cli.App {
 	sign.Flags = []cli.Flag{
 		privateKeyFlag,
 		gcpKMSKeyFlag,
+		signserverWorkerName,
 		vaultTransitKeyFlag,
 		cli.StringFlag{
 			Name: "output-path, o",
@@ -523,6 +563,7 @@ func getCliContext() *cli.App {
 			Usage: "Force creating new signature if the artifact is already signed",
 		},
 		pkcs11Flag,
+		azureKeyFlag,
 	}
 
 	//
@@ -564,6 +605,7 @@ func getCliContext() *cli.App {
 		artifactNameDepends,
 		artifactProvidesGroup,
 		artifactDependsGroups,
+		artifactAddScripts,
 		payloadProvides,
 		payloadDepends,
 		payloadMetaData,
@@ -578,8 +620,10 @@ func getCliContext() *cli.App {
 		},
 		privateKeyFlag,
 		gcpKMSKeyFlag,
+		signserverWorkerName,
 		vaultTransitKeyFlag,
 		compressionFlag,
+		azureKeyFlag,
 	}
 	modify.Before = func(c *cli.Context) error {
 		if c.String("name") != "" {
@@ -603,7 +647,9 @@ func getCliContext() *cli.App {
 		compressionFlag,
 		privateKeyFlag,
 		gcpKMSKeyFlag,
+		signserverWorkerName,
 		vaultTransitKeyFlag,
+		azureKeyFlag,
 	}
 
 	cat := cli.Command{
