@@ -17,10 +17,10 @@ package cli
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"regexp"
+	"strings"
 
 	"github.com/urfave/cli"
 )
@@ -94,7 +94,13 @@ func Copy(c *cli.Context) (err error) {
 		if err != nil {
 			return cli.NewExitError(err, 1)
 		}
-		vfile, err = virtualImage.OpenFile(privateKey, c.Args().Get(1))
+
+		dstPath := c.Args().Get(1)
+		if strings.HasSuffix(c.Args().Get(1), "/") {
+			dstPath = dstPath + filepath.Base(c.Args().First())
+		}
+
+		vfile, err = virtualImage.OpenFile(privateKey, dstPath)
 		defer wclose(vfile)
 		if err != nil {
 			return cli.NewExitError(err, 1)
@@ -295,7 +301,7 @@ func parseCLIOptions(c *cli.Context) int {
 // current file, with the permissions given by perm.
 func createTmpFileWithPerm(f *os.File, perm os.FileMode) (string, error) {
 
-	td, err := ioutil.TempDir("", "mender-artifact-install")
+	td, err := os.MkdirTemp("", "mender-artifact-install")
 	if err != nil {
 		return "", err
 	}
