@@ -16,7 +16,6 @@ package cli
 
 import (
 	"io"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -54,7 +53,7 @@ func copyFile(src, dst string) error {
 }
 
 func TestDebugfs(t *testing.T) {
-	tmp, err := ioutil.TempDir("", "mender-modify")
+	tmp, err := os.MkdirTemp("", "mender-modify")
 	assert.NoError(t, err)
 
 	defer os.RemoveAll(tmp)
@@ -72,7 +71,7 @@ func TestDebugfs(t *testing.T) {
 	assert.NoError(t, err)
 	assert.Equal(t, false, st.IsDir())
 
-	tFile, err := ioutil.TempFile("", "test-mender-debugfs")
+	tFile, err := os.CreateTemp("", "test-mender-debugfs")
 	assert.NoError(t, err)
 
 	defer os.Remove(tFile.Name())
@@ -87,7 +86,11 @@ func TestDebugfs(t *testing.T) {
 		filepath.Join(tmp, "mender_test.img"))
 	assert.NoError(t, err)
 
-	err = debugfsReplaceFile("/nonexisting/foo.txt", tFile.Name(), filepath.Join(tmp, "mender_test.img"))
+	err = debugfsReplaceFile(
+		"/nonexisting/foo.txt",
+		tFile.Name(),
+		filepath.Join(tmp, "mender_test.img"),
+	)
 	assert.Error(t, err)
 
 	os.RemoveAll(tDir)
@@ -100,7 +103,7 @@ func verify(image, file, expected string) bool {
 	}
 	defer os.RemoveAll(tmp)
 
-	data, err := ioutil.ReadFile(filepath.Join(tmp, filepath.Base(file)))
+	data, err := os.ReadFile(filepath.Join(tmp, filepath.Base(file)))
 	if err != nil {
 		return false
 	}
@@ -127,7 +130,7 @@ func verifySDImg(image, file, expected string) bool {
 func TestModifyImage(t *testing.T) {
 	skipPartedTestsOnMac(t)
 
-	tmp, err := ioutil.TempDir("", "mender-modify")
+	tmp, err := os.MkdirTemp("", "mender-modify")
 	assert.NoError(t, err)
 
 	defer os.RemoveAll(tmp)
@@ -173,7 +176,7 @@ func TestModifyImage(t *testing.T) {
 func TestModifySdimage(t *testing.T) {
 	skipPartedTestsOnMac(t)
 
-	tmp, err := ioutil.TempDir("", "mender-modify")
+	tmp, err := os.MkdirTemp("", "mender-modify")
 	assert.NoError(t, err)
 
 	defer os.RemoveAll(tmp)
@@ -217,7 +220,7 @@ func modifyAndRead(t *testing.T, artFile string, args ...string) string {
 		goErr <- err
 	}()
 
-	data, err := ioutil.ReadAll(r)
+	data, err := io.ReadAll(r)
 	require.NoError(t, err)
 	err = <-goErr
 	require.NoError(t, err)
@@ -226,7 +229,7 @@ func modifyAndRead(t *testing.T, artFile string, args ...string) string {
 }
 
 func TestModifyRootfsArtifact(t *testing.T) {
-	tmp, err := ioutil.TempDir("", "mender-modify")
+	tmp, err := os.MkdirTemp("", "mender-modify")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmp)
 
@@ -245,7 +248,7 @@ func TestModifyRootfsArtifact(t *testing.T) {
 func TestModifyRootfsServerCert(t *testing.T) {
 	skipPartedTestsOnMac(t)
 
-	tmp, err := ioutil.TempDir("", "mender-modify")
+	tmp, err := os.MkdirTemp("", "mender-modify")
 	assert.NoError(t, err)
 	defer os.RemoveAll(tmp)
 
@@ -261,7 +264,7 @@ func TestModifyRootfsServerCert(t *testing.T) {
 	assert.Error(t, err)
 	assert.Contains(t, fakeErrWriter.String(), "invalid server certificate")
 
-	tmpCert, err := ioutil.TempFile("", "mender-test-cert")
+	tmpCert, err := os.CreateTemp("", "mender-test-cert")
 	assert.NoError(t, err)
 	defer os.Remove(tmpCert.Name())
 
@@ -301,9 +304,9 @@ yOTl4wVLQKA6mFvMV9o8B9yTBNg3mQS0vA==
 func removeVolatileEntries(input string) string {
 	var output strings.Builder
 	for _, line := range strings.Split(input, "\n") {
-		if strings.HasPrefix(line, "      checksum:") ||
-			strings.HasPrefix(line, "      modified:") ||
-			strings.HasPrefix(line, "\trootfs-image.checksum:") {
+		if strings.Contains(line, " checksum:") ||
+			strings.Contains(line, " modified:") ||
+			strings.Contains(line, "rootfs-image.checksum:") {
 			continue
 		}
 		output.WriteString(line)
@@ -313,17 +316,17 @@ func removeVolatileEntries(input string) string {
 }
 
 func TestModifyRootfsSigned(t *testing.T) {
-	tmp, err := ioutil.TempDir("", "mender-modify")
+	tmp, err := os.MkdirTemp("", "mender-modify")
 	assert.NoError(t, err)
 	defer os.RemoveAll(tmp)
 
 	err = copyFile("mender_test.img", filepath.Join(tmp, "mender_test.img"))
 	assert.NoError(t, err)
 
-	err = ioutil.WriteFile(filepath.Join(tmp, "rsa.key"), []byte(PrivateRSAKey), 0711)
+	err = os.WriteFile(filepath.Join(tmp, "rsa.key"), []byte(PrivateRSAKey), 0711)
 	assert.NoError(t, err)
 
-	err = ioutil.WriteFile(filepath.Join(tmp, "ecdsa.key"), []byte(PrivateECDSAKey), 0711)
+	err = os.WriteFile(filepath.Join(tmp, "ecdsa.key"), []byte(PrivateECDSAKey), 0711)
 	assert.NoError(t, err)
 
 	for _, key := range []string{"rsa.key", "ecdsa.key"} {
@@ -338,28 +341,27 @@ func TestModifyRootfsSigned(t *testing.T) {
 
 		// Modify the artifact, the result shall be unsigned
 		data := modifyAndRead(t, filepath.Join(tmp, "artifact.mender"), "-n", "release-2")
-		expected := `Mender artifact:
+		expected := `Mender Artifact:
   Name: release-2
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[my-device]'
+  Compatible devices: [my-device]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   rootfs-image
+  - Type: rootfs-image
     Provides:
-	rootfs-image.version: release-1
-    Depends: Nothing
-    Clears Provides: ["artifact_group", "rootfs_image_checksum", "rootfs-image.*"]
-    Metadata: Nothing
+      rootfs-image.version: release-1
+    Depends: {}
+    Clears Provides: [artifact_group, rootfs_image_checksum, rootfs-image.*]
+    Metadata: {}
     Files:
-      name:     mender_test.img
-      size:     524288
+        name: mender_test.img
+        size: 524288
 
 `
 		assert.Equal(t, expected, removeVolatileEntries(data))
@@ -367,28 +369,27 @@ Updates:
 		// Modify again with a private key, and the result shall be signed
 		data = modifyAndRead(t, filepath.Join(tmp, "artifact.mender"),
 			"-n", "release-3", "-k", filepath.Join(tmp, key))
-		expected = `Mender artifact:
+		expected = `Mender Artifact:
   Name: release-3
   Format: mender
   Version: 3
   Signature: signed but no key for verification provided; please use ` + "`-k`" + ` option for providing verification key
-  Compatible devices: '[my-device]'
+  Compatible devices: [my-device]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   rootfs-image
+  - Type: rootfs-image
     Provides:
-	rootfs-image.version: release-1
-    Depends: Nothing
-    Clears Provides: ["artifact_group", "rootfs_image_checksum", "rootfs-image.*"]
-    Metadata: Nothing
+      rootfs-image.version: release-1
+    Depends: {}
+    Clears Provides: [artifact_group, rootfs_image_checksum, rootfs-image.*]
+    Metadata: {}
     Files:
-      name:     mender_test.img
-      size:     524288
+        name: mender_test.img
+        size: 524288
 
 `
 		assert.Equal(t, expected, removeVolatileEntries(data))
@@ -396,9 +397,13 @@ Updates:
 
 	// Make sure scripts are preserved.
 
-	err = ioutil.WriteFile(filepath.Join(tmp, "ArtifactInstall_Enter_00"), []byte("commands"), 0755)
+	err = os.WriteFile(filepath.Join(tmp, "ArtifactInstall_Enter_00"), []byte("commands"), 0755)
 	require.NoError(t, err)
-	err = ioutil.WriteFile(filepath.Join(tmp, "ArtifactCommit_Leave_00"), []byte("more commands"), 0755)
+	err = os.WriteFile(
+		filepath.Join(tmp, "ArtifactCommit_Leave_00"),
+		[]byte("more commands"),
+		0755,
+	)
 	require.NoError(t, err)
 
 	err = Run([]string{
@@ -419,18 +424,18 @@ Updates:
 	// State scripts can unfortunately be in any order.
 	var expectedScripts string
 	if strings.Index(data, "ArtifactInstall") < strings.Index(data, "ArtifactCommit") {
-		expectedScripts = `    ArtifactInstall_Enter_00
-    ArtifactCommit_Leave_00`
+		expectedScripts = `    - ArtifactInstall_Enter_00
+    - ArtifactCommit_Leave_00`
 	} else {
-		expectedScripts = `    ArtifactCommit_Leave_00
-    ArtifactInstall_Enter_00`
+		expectedScripts = `    - ArtifactCommit_Leave_00
+    - ArtifactInstall_Enter_00`
 	}
-	expected := `Mender artifact:
+	expected := `Mender Artifact:
   Name: release-2
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[my-device]'
+  Compatible devices: [my-device]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
@@ -438,26 +443,27 @@ Updates:
 ` + expectedScripts + `
 
 Updates:
-    0:
-    Type:   rootfs-image
+  - Type: rootfs-image
     Provides:
-	rootfs-image.version: release-1
-    Depends: Nothing
-    Clears Provides: ["artifact_group", "rootfs_image_checksum", "rootfs-image.*"]
-    Metadata: Nothing
+      rootfs-image.version: release-1
+    Depends: {}
+    Clears Provides: [artifact_group, rootfs_image_checksum, rootfs-image.*]
+    Metadata: {}
     Files:
-      name:     mender_test.img
-      size:     524288
+        name: mender_test.img
+        size: 524288
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
 
 	modifyWriteFlagsTested.addFlags([]string{
 		"artifact-name",
+		"azure-key",
 		"compression",
 		"device-type",
 		"file",
 		"gcp-kms-key",
+		"keyfactor-signserver-worker",
 		"vault-transit-key",
 		"key",
 		"output-path",
@@ -465,7 +471,9 @@ Updates:
 	})
 	modifyFlagsTested.addFlags([]string{
 		"artifact-name",
+		"azure-key",
 		"gcp-kms-key",
+		"keyfactor-signserver-worker",
 		"vault-transit-key",
 		"key",
 		"name",
@@ -474,15 +482,15 @@ Updates:
 
 func TestModifyModuleArtifact(t *testing.T) {
 
-	tmpdir, err := ioutil.TempDir("", "mendertest")
+	tmpdir, err := os.MkdirTemp("", "mendertest")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 	artfile := filepath.Join(tmpdir, "artifact.mender")
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "updateFile2"), []byte("updateContent2"), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "updateFile2"), []byte("updateContent2"), 0644)
 	require.NoError(t, err)
 
 	err = Run([]string{
@@ -498,30 +506,29 @@ func TestModifyModuleArtifact(t *testing.T) {
 
 	// Modify Artifact name shall work
 	data := modifyAndRead(t, artfile, "-n", "release-1")
-	expected := `Mender artifact:
+	expected := `Mender Artifact:
   Name: release-1
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[testDevice]'
+  Compatible devices: [testDevice]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   testType
+  - Type: testType
     Provides:
-	rootfs-image.testType.version: testName
-    Depends: Nothing
-    Clears Provides: ["rootfs-image.testType.*"]
-    Metadata: Nothing
+      rootfs-image.testType.version: testName
+    Depends: {}
+    Clears Provides: [rootfs-image.testType.*]
+    Metadata: {}
     Files:
-      name:     updateFile
-      size:     13
-      name:     updateFile2
-      size:     14
+        name: updateFile
+        size: 13
+        name: updateFile2
+        size: 14
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
@@ -533,7 +540,7 @@ Updates:
 	assert.Error(t, err)
 	assert.Contains(t, err.Error(), errFsTypeUnsupported.Error())
 
-	require.NoError(t, ioutil.WriteFile("dummy-cert", []byte("SecretCert"), 0644))
+	require.NoError(t, os.WriteFile("dummy-cert", []byte("SecretCert"), 0644))
 	defer os.Remove("dummy-cert")
 	err = Run([]string{
 		"mender-artifact", "modify", "-c", "dummy-cert", artfile,
@@ -541,7 +548,7 @@ Updates:
 	assert.Error(t, err)
 	assert.Contains(t, err.Error(), errFsTypeUnsupported.Error())
 
-	require.NoError(t, ioutil.WriteFile("dummy-key", []byte("SecretKey"), 0644))
+	require.NoError(t, os.WriteFile("dummy-key", []byte("SecretKey"), 0644))
 	defer os.Remove("dummy-key")
 	err = Run([]string{
 		"mender-artifact", "modify", "-v", "dummy-key", artfile,
@@ -557,13 +564,25 @@ Updates:
 
 	// Make sure scripts and meta-data are preserved.
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "ArtifactInstall_Enter_00"), []byte("commands"), 0755)
+	err = os.WriteFile(
+		filepath.Join(tmpdir, "ArtifactInstall_Enter_00"),
+		[]byte("commands"),
+		0755,
+	)
 	require.NoError(t, err)
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "ArtifactCommit_Leave_00"), []byte("more commands"), 0755)
+	err = os.WriteFile(
+		filepath.Join(tmpdir, "ArtifactCommit_Leave_00"),
+		[]byte("more commands"),
+		0755,
+	)
 	require.NoError(t, err)
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "meta-data"), []byte(`{"a":"b"}`), 0644)
+	err = os.WriteFile(
+		filepath.Join(tmpdir, "ArtifactRollback_Enter_00"),
+		[]byte("even more commands"),
+		0755,
+	)
+	err = os.WriteFile(filepath.Join(tmpdir, "meta-data"), []byte(`{"a":"b"}`), 0644)
 	require.NoError(t, err)
-
 	err = Run([]string{
 		"mender-artifact", "write", "module-image",
 		"-o", artfile,
@@ -572,29 +591,66 @@ Updates:
 		"-T", "testType",
 		"-f", filepath.Join(tmpdir, "updateFile"),
 		"-f", filepath.Join(tmpdir, "updateFile2"),
-		"-s", filepath.Join(tmpdir, "ArtifactInstall_Enter_00"),
+		// Only writes one of the scripts during the write operation to add them later with modify
 		"-s", filepath.Join(tmpdir, "ArtifactCommit_Leave_00"),
 		"-m", filepath.Join(tmpdir, "meta-data"),
 	})
 	assert.NoError(t, err)
 
+	// Adds the other script via modifying
+	modifyAndRead(
+		t,
+		artfile,
+		"-s",
+		filepath.Join(tmpdir, "ArtifactInstall_Enter_00"),
+		"-s",
+		filepath.Join(tmpdir, "ArtifactRollback_Enter_00"),
+	)
+
 	// Modify Artifact name shall work
 	data = modifyAndRead(t, artfile, "-n", "release-1")
-	// State scripts can unfortunately be in any order.
+	// State scripts can unfortunately be in any order, so we have to compare their placement before expecting a result with them
 	var expectedScripts string
-	if strings.Index(string(data), "ArtifactInstall") < strings.Index(string(data), "ArtifactCommit") {
-		expectedScripts = `    ArtifactInstall_Enter_00
-    ArtifactCommit_Leave_00`
+	installIndex := strings.Index(string(data), "ArtifactInstall")
+	commitIndex := strings.Index(string(data), "ArtifactCommit")
+	rollbackIndex := strings.Index(string(data), "ArtifactRollback")
+
+	if installIndex < commitIndex {
+		if commitIndex < rollbackIndex {
+			expectedScripts = `    - ArtifactCommmit_Leave_00 
+    - ArtifactRollback_Enter_00
+    - ArtifactInstall_Enter_00`
+		} else if installIndex < rollbackIndex {
+			expectedScripts = `    - ArtifactInstall_Enter_00
+    - ArtifactRollback_Enter_00
+    - ArtifactCommit_Leave_00`
+		} else {
+			expectedScripts = `    - ArtifactInstall_Enter_00
+    - ArtifactCommit_Leave_00
+    - ArtifactRollback_Enter_00`
+		}
 	} else {
-		expectedScripts = `    ArtifactCommit_Leave_00
-    ArtifactInstall_Enter_00`
+		if installIndex < rollbackIndex {
+			expectedScripts = `    - ArtifactCommit_Leave_00
+    - ArtifactInstall_Enter_00
+    - ArtifactRollback_Enter_00`
+		} else if commitIndex < rollbackIndex {
+			expectedScripts = `    - ArtifactCommit_Leave_00
+    - ArtifactRollback_Enter_00
+    - ArtifactInstall_Enter_00`
+		} else {
+			expectedScripts = `    - ArtifactRollback_Enter_00
+    - ArtifactCommit_Leave_00
+    - ArtifactInstall_Enter_00`
+		}
 	}
-	expected = `Mender artifact:
+
+	expected = `Mender Artifact:
   Name: release-1
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[testDevice]'
+  Compatible devices: [testDevice]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
@@ -602,21 +658,20 @@ Updates:
 ` + expectedScripts + `
 
 Updates:
-    0:
-    Type:   testType
+  - Type: testType
     Provides:
-	rootfs-image.testType.version: testName
-    Depends: Nothing
-    Clears Provides: ["rootfs-image.testType.*"]
+      rootfs-image.testType.version: testName
+    Depends: {}
+    Clears Provides: [rootfs-image.testType.*]
     Metadata:
-	{
-	  "a": "b"
-	}
+      {
+        "a": "b"
+      }
     Files:
-      name:     updateFile
-      size:     13
-      name:     updateFile2
-      size:     14
+        name: updateFile
+        size: 13
+        name: updateFile2
+        size: 14
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
@@ -634,18 +689,19 @@ Updates:
 		"server-uri",
 		"tenant-token",
 		"verification-key",
+		"script",
 	})
 }
 
 func TestModifyBrokenArtifact(t *testing.T) {
 	skipPartedTestsOnMac(t)
 
-	tmpdir, err := ioutil.TempDir("", "")
+	tmpdir, err := os.MkdirTemp("", "")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 
 	artFile := filepath.Join(tmpdir, "artifact.mender")
-	err = ioutil.WriteFile(artFile, []byte("bogus content"), 0644)
+	err = os.WriteFile(artFile, []byte("bogus content"), 0644)
 	require.NoError(t, err)
 
 	err = Run([]string{
@@ -657,15 +713,15 @@ func TestModifyBrokenArtifact(t *testing.T) {
 }
 
 func TestModifyExtraAttributes(t *testing.T) {
-	tmpdir, err := ioutil.TempDir("", "mendertest")
+	tmpdir, err := os.MkdirTemp("", "mendertest")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 	artfile := filepath.Join(tmpdir, "artifact.mender")
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "meta-data"), []byte(`{"meta":"data"}`), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "meta-data"), []byte(`{"meta":"data"}`), 0644)
 	require.NoError(t, err)
 
 	err = Run([]string{
@@ -697,33 +753,33 @@ func TestModifyExtraAttributes(t *testing.T) {
 		"--depends", "testDepends2:SomeStuff2",
 		"--meta-data", filepath.Join(tmpdir, "meta-data"),
 	)
-	expected := `Mender artifact:
+	expected := `Mender Artifact:
   Name: testName
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[testDevice]'
+  Compatible devices: [testDevice]
   Provides group: testProvidesGroup
   Depends on one of artifact(s): [testNameDepends, testNameDepends2]
   Depends on one of group(s): [testDependsGroup, testDependsGroup2]
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   testType
+  - Type: testType
     Provides:
-	testProvide1: SomeStuff1
-	testProvide2: SomeStuff2
+      testProvide1: SomeStuff1
+      testProvide2: SomeStuff2
     Depends:
-	testDepends1: SomeStuff1
-	testDepends2: SomeStuff2
+      testDepends1: SomeStuff1
+      testDepends2: SomeStuff2
+    Clears Provides: []
     Metadata:
-	{
-	  "meta": "data"
-	}
+      {
+        "meta": "data"
+      }
     Files:
-      name:     updateFile
-      size:     13
+        name: updateFile
+        size: 13
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
@@ -766,7 +822,7 @@ Updates:
 func TestModifyExtraAttributesOnNonArtifact(t *testing.T) {
 	skipPartedTestsOnMac(t)
 
-	tmpdir, err := ioutil.TempDir("", "")
+	tmpdir, err := os.MkdirTemp("", "")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 
@@ -774,7 +830,7 @@ func TestModifyExtraAttributesOnNonArtifact(t *testing.T) {
 	err = copyFile("mender_test.img", art)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "meta-data"), []byte(`{"meta":"data"}`), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "meta-data"), []byte(`{"meta":"data"}`), 0644)
 	require.NoError(t, err)
 
 	paramPairs := [][]string{
@@ -802,7 +858,7 @@ func testModifyExtraAttributesOnNonArtifact(t *testing.T, art string, p []string
 }
 
 func TestModifyClearsProvides(t *testing.T) {
-	tmpdir, err := ioutil.TempDir("", "mendertest")
+	tmpdir, err := os.MkdirTemp("", "mendertest")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 	artfile := filepath.Join(tmpdir, "artifact.mender")
@@ -820,26 +876,25 @@ func TestModifyClearsProvides(t *testing.T) {
 	data := modifyAndRead(t, artfile, "--clears-provides", "my-fs.*",
 		"--delete-clears-provides", "rootfs-image.testType.*",
 	)
-	expected := `Mender artifact:
+	expected := `Mender Artifact:
   Name: testName
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[testDevice]'
+  Compatible devices: [testDevice]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   testType
+  - Type: testType
     Provides:
-	rootfs-image.testType.version: testName
-    Depends: Nothing
-    Clears Provides: ["my-fs.*"]
-    Metadata: Nothing
-    Files: None
+      rootfs-image.testType.version: testName
+    Depends: {}
+    Clears Provides: [my-fs.*]
+    Metadata: {}
+    Files: []
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
@@ -862,12 +917,12 @@ Updates:
 }
 
 func TestModifyNoProvides(t *testing.T) {
-	tmpdir, err := ioutil.TempDir("", "mendertest")
+	tmpdir, err := os.MkdirTemp("", "mendertest")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 	artfile := filepath.Join(tmpdir, "artifact.mender")
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
 	require.NoError(t, err)
 
 	err = Run([]string{
@@ -882,26 +937,26 @@ func TestModifyNoProvides(t *testing.T) {
 	require.NoError(t, err)
 
 	data := modifyAndRead(t, artfile)
-	expected := `Mender artifact:
+	expected := `Mender Artifact:
   Name: testName
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[testDevice]'
+  Compatible devices: [testDevice]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   rootfs-image
-    Provides: Nothing
-    Depends: Nothing
-    Metadata: Nothing
+  - Type: rootfs-image
+    Provides: {}
+    Depends: {}
+    Clears Provides: []
+    Metadata: {}
     Files:
-      name:     updateFile
-      size:     13
+        name: updateFile
+        size: 13
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
@@ -922,12 +977,12 @@ Updates:
 }
 
 func TestModifyCompression(t *testing.T) {
-	tmpdir, err := ioutil.TempDir("", "mendertest")
+	tmpdir, err := os.MkdirTemp("", "mendertest")
 	require.NoError(t, err)
 	defer os.RemoveAll(tmpdir)
 	artfile := filepath.Join(tmpdir, "artifact.mender")
 
-	err = ioutil.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
+	err = os.WriteFile(filepath.Join(tmpdir, "updateFile"), []byte("updateContent"), 0644)
 	require.NoError(t, err)
 
 	err = Run([]string{
@@ -940,28 +995,27 @@ func TestModifyCompression(t *testing.T) {
 	require.NoError(t, err)
 
 	data := modifyAndRead(t, artfile, "--compression", "lzma")
-	expected := `Mender artifact:
+	expected := `Mender Artifact:
   Name: testName
   Format: mender
   Version: 3
   Signature: no signature
-  Compatible devices: '[testDevice]'
+  Compatible devices: [testDevice]
   Provides group: 
   Depends on one of artifact(s): []
   Depends on one of group(s): []
-  State scripts:
+  State scripts: []
 
 Updates:
-    0:
-    Type:   rootfs-image
+  - Type: rootfs-image
     Provides:
-	rootfs-image.version: testName
-    Depends: Nothing
-    Clears Provides: ["artifact_group", "rootfs_image_checksum", "rootfs-image.*"]
-    Metadata: Nothing
+      rootfs-image.version: testName
+    Depends: {}
+    Clears Provides: [artifact_group, rootfs_image_checksum, rootfs-image.*]
+    Metadata: {}
     Files:
-      name:     updateFile
-      size:     13
+        name: updateFile
+        size: 13
 
 `
 	assert.Equal(t, expected, removeVolatileEntries(data))
