@@ -1,4 +1,4 @@
-// Copyright 2022 Northern.tech AS
+// Copyright 2023 Northern.tech AS
 //
 //    Licensed under the Apache License, Version 2.0 (the "License");
 //    you may not use this file except in compliance with the License.
@@ -15,7 +15,6 @@
 package cli
 
 import (
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -27,7 +26,7 @@ import (
 
 func TestSignExistingV2(t *testing.T) {
 	// first create archive, that we will be able to read
-	updateTestDir, _ := ioutil.TempDir("", "update")
+	updateTestDir, _ := os.MkdirTemp("", "update")
 	defer os.RemoveAll(updateTestDir)
 
 	priv, pub, err := generateKeys()
@@ -79,7 +78,7 @@ func TestSignExistingV2(t *testing.T) {
 }
 
 func TestSignExistingWithScripts(t *testing.T) {
-	updateTestDir, _ := ioutil.TempDir("", "update")
+	updateTestDir, _ := os.MkdirTemp("", "update")
 	defer os.RemoveAll(updateTestDir)
 
 	priv, pub, err := generateKeys()
@@ -145,7 +144,7 @@ func TestSignExistingWithScripts(t *testing.T) {
 }
 
 func TestSignExistingWithModules(t *testing.T) {
-	updateTestDir, _ := ioutil.TempDir("", "update")
+	updateTestDir, _ := os.MkdirTemp("", "update")
 	defer os.RemoveAll(updateTestDir)
 
 	priv, pub, err := generateKeys()
@@ -209,7 +208,7 @@ func TestSignExistingWithModules(t *testing.T) {
 }
 
 func TestSignExistingBrokenFiles(t *testing.T) {
-	updateTestDir, _ := ioutil.TempDir("", "update")
+	updateTestDir, _ := os.MkdirTemp("", "update")
 	defer os.RemoveAll(updateTestDir)
 
 	priv, pub, err := generateKeys()
@@ -255,7 +254,7 @@ func TestSignExistingBrokenFiles(t *testing.T) {
 }
 
 func TestSignWithWriteCommand(t *testing.T) {
-	updateTestDir, _ := ioutil.TempDir("", "update")
+	updateTestDir, _ := os.MkdirTemp("", "update")
 	defer os.RemoveAll(updateTestDir)
 
 	priv, pub, err := generateKeys()
@@ -324,3 +323,76 @@ func TestSignWithWriteCommand(t *testing.T) {
 		assert.Contains(t, artifactTarLines, "manifest.sig")
 	})
 }
+
+func TestSignExistingPermissions(t *testing.T) {
+	// first create archive, that we will be able to read
+	updateTestDir, _ := os.MkdirTemp("", "update")
+	defer os.RemoveAll(updateTestDir)
+
+	priv, _, err := generateKeys()
+	assert.NoError(t, err)
+
+	err = WriteArtifact(updateTestDir, 2, "")
+	assert.NoError(t, err)
+
+	err = MakeFakeUpdateDir(updateTestDir,
+		[]TestDirEntry{
+			{
+				Path:    "private.key",
+				Content: priv,
+				IsDir:   false,
+			},
+		})
+	assert.NoError(t, err)
+
+	err = Run([]string{"mender-artifact", "sign",
+		"-k", filepath.Join(updateTestDir, "private.key"),
+		"-o", filepath.Join(updateTestDir, "artifact.mender.sig"),
+		filepath.Join(updateTestDir, "artifact.mender")})
+	assert.NoError(t, err)
+
+	preSignStat, _ := os.Stat(filepath.Join(updateTestDir, "artifact.mender"))
+	postSignStat, err := os.Stat(filepath.Join(updateTestDir, "artifact.mender.sig"))
+
+	assert.Equal(t, preSignStat.Mode(), postSignStat.Mode())
+}
+func TestSignViaSymlink(t *testing.T) {
+	updateTestDir, _ := os.MkdirTemp("", "update")
+	defer os.RemoveAll(updateTestDir)
+
+	priv, pub, err := generateKeys()
+	assert.NoError(t, err)
+
+	err = WriteArtifact(updateTestDir, 2, "")
+	assert.NoError(t, err)
+
+	err = MakeFakeUpdateDir(updateTestDir,
+		[]TestDirEntry{
+			{
+				Path:    "private.key",
+				Content: priv,
+				IsDir:   false,
+			},
+			{
+				Path:    "public.key",
+				Content: pub,
+				IsDir:   false,
+			},
+		})
+	assert.NoError(t, err)
+
+	symlink := filepath.Join(updateTestDir, "symlink")
+	os.Symlink(filepath.Join(updateTestDir, "artifact.mender"), symlink)
+
+	// signing the symlink
+	err = Run([]string{"mender-artifact", "sign",
+		"-k", filepath.Join(updateTestDir, "private.key"),
+		symlink})
+	assert.NoError(t, err)
+
+	// validating the orignal artifact
+	err = Run([]string{"mender-artifact", "validate",
+		"-k", filepath.Join(updateTestDir, "public.key"),
+		filepath.Join(updateTestDir, "artifact.mender")})
+	assert.NoError(t, err)
+}
