@@ -1,4 +1,4 @@
-// Copyright 2022 Northern.tech AS
+// Copyright 2023 Northern.tech AS
 //
 //    Licensed under the Apache License, Version 2.0 (the "License");
 //    you may not use this file except in compliance with the License.
@@ -28,7 +28,6 @@ import (
 	"time"
 
 	"io"
-	"io/ioutil"
 
 	"github.com/pkg/errors"
 	"github.com/urfave/cli"
@@ -43,7 +42,7 @@ import (
 
 func writeRootfsImageChecksum(rootfsFilename string,
 	typeInfo *artifact.TypeInfoV3, legacy bool) (err error) {
-	chk := artifact.NewWriterChecksum(ioutil.Discard)
+	chk := artifact.NewWriterChecksum(io.Discard)
 	payload, err := os.Open(rootfsFilename)
 	if err != nil {
 		return cli.NewExitError(
@@ -68,7 +67,7 @@ func writeRootfsImageChecksum(rootfsFilename string,
 	if typeInfo.ArtifactProvides == nil {
 		t, err := artifact.NewTypeInfoProvides(map[string]string{checksumKey: checksum})
 		if err != nil {
-			return errors.Wrapf(err, "Failed to write the "+"`"+checksumKey+"` provides")
+			return errors.Wrapf(err, "%s", "Failed to write the "+"`"+checksumKey+"` provides")
 		}
 		typeInfo.ArtifactProvides = t
 	} else {
@@ -103,6 +102,10 @@ func validateInput(c *cli.Context) error {
 }
 
 func createRootfsFromSSH(c *cli.Context) (string, error) {
+	_, err := utils.GetBinaryPath("blkid")
+	if err != nil {
+		Log.Warnf("Skipping running fsck on the Artifact: %v", errBlkidNotFound)
+	}
 	rootfsFilename, err := getDeviceSnapshot(c)
 	if err != nil {
 		return rootfsFilename, cli.NewExitError("SSH error: "+err.Error(), 1)
@@ -112,7 +115,6 @@ func createRootfsFromSSH(c *cli.Context) (string, error) {
 	fstype, err := imgFilesystemType(rootfsFilename)
 	if err != nil {
 		if err == errBlkidNotFound {
-			Log.Warnf("Skipping running fsck on the Artifact: %v", err)
 			return rootfsFilename, nil
 		}
 		return rootfsFilename, cli.NewExitError(
@@ -178,21 +180,22 @@ func writeBootstrapArtifact(c *cli.Context) error {
 
 	Log.Debugf("creating bootstrap artifact [%s], version: %d", name, version)
 
-	f, err := os.Create(name + ".tmp")
-	if err != nil {
-		return cli.NewExitError(
-			"can not create bootstrap artifact file: "+err.Error(),
-			errArtifactCreate,
-		)
+	var w io.Writer
+	if name == "-" {
+		w = os.Stdout
+	} else {
+		f, err := os.Create(name)
+		if err != nil {
+			return cli.NewExitError(
+				"can not create bootstrap artifact file: "+err.Error(),
+				errArtifactCreate,
+			)
+		}
+		defer f.Close()
+		w = f
 	}
-	defer func() {
-		f.Close()
-		// in case of success `.tmp` suffix will be removed and below
-		// will not remove valid artifact
-		os.Remove(name + ".tmp")
-	}()
 
-	aw, err := artifactWriter(c, comp, f, version)
+	aw, err := artifactWriter(c, comp, w, version)
 	if err != nil {
 		return cli.NewExitError(err.Error(), 1)
 	}
@@ -241,12 +244,6 @@ func writeBootstrapArtifact(c *cli.Context) error {
 	if err != nil {
 		return cli.NewExitError(err.Error(), 1)
 	}
-
-	f.Close()
-	err = os.Rename(name+".tmp", name)
-	if err != nil {
-		return cli.NewExitError(err.Error(), 1)
-	}
 	return nil
 }
 
@@ -270,6 +267,7 @@ func writeRootfs(c *cli.Context) error {
 		name = c.String("output-path")
 	}
 	version := c.Int("version")
+	var showprovides map[string]string
 
 	Log.Debugf("creating artifact [%s], version: %d", name, version)
 	rootfsFilename := c.String("file")
@@ -279,6 +277,10 @@ func writeRootfs(c *cli.Context) error {
 		if err != nil {
 			return cli.NewExitError(err.Error(), errArtifactCreate)
 		}
+		showprovides, err = showProvides(c)
+		if err != nil {
+			return cli.NewExitError(err.Error(), errArtifactCreate)
+		}
 	}
 
 	var h handlers.Composer
@@ -298,21 +300,22 @@ func writeRootfs(c *cli.Context) error {
 		Updates: []handlers.Composer{h},
 	}
 
-	f, err := os.Create(name + ".tmp")
-	if err != nil {
-		return cli.NewExitError(
-			"can not create artifact file: "+err.Error(),
-			errArtifactCreate,
-		)
+	var w io.Writer
+	if name == "-" {
+		w = os.Stdout
+	} else {
+		f, err := os.Create(name)
+		if err != nil {
+			return cli.NewExitError(
+				"can not create artifact file: "+err.Error(),
+				errArtifactCreate,
+			)
+		}
+		defer f.Close()
+		w = f
 	}
-	defer func() {
-		f.Close()
-		// in case of success `.tmp` suffix will be removed and below
-		// will not remove valid artifact
-		os.Remove(name + ".tmp")
-	}()
 
-	aw, err := artifactWriter(c, comp, f, version)
+	aw, err := artifactWriter(c, comp, w, version)
 	if err != nil {
 		return cli.NewExitError(err.Error(), 1)
 	}
@@ -337,6 +340,12 @@ func writeRootfs(c *cli.Context) error {
 	if err != nil {
 		return err
 	}
+	for k, v := range showprovides {
+		_, exist := typeInfoV3.ArtifactProvides[k]
+		if !exist {
+			typeInfoV3.ArtifactProvides[k] = v
+		}
+	}
 
 	if !c.Bool("no-checksum-provide") {
 		legacy := c.Bool("legacy-rootfs-image-checksum")
@@ -347,7 +356,6 @@ func writeRootfs(c *cli.Context) error {
 			)
 		}
 	}
-
 	if !c.Bool("no-progress") {
 		ctx, cancel := context.WithCancel(context.Background())
 		go reportProgress(ctx, aw.State)
@@ -370,12 +378,6 @@ func writeRootfs(c *cli.Context) error {
 	if err != nil {
 		return cli.NewExitError(err.Error(), 1)
 	}
-
-	f.Close()
-	err = os.Rename(name+".tmp", name)
-	if err != nil {
-		return cli.NewExitError(err.Error(), 1)
-	}
 	return nil
 }
 
@@ -400,7 +402,7 @@ func reportProgress(c context.Context, state chan string) {
 	}
 }
 
-func artifactWriter(c *cli.Context, comp artifact.Compressor, f *os.File,
+func artifactWriter(c *cli.Context, comp artifact.Compressor, w io.Writer,
 	ver int) (*awriter.Writer, error) {
 	privateKey, err := getKey(c)
 	if err != nil {
@@ -411,9 +413,9 @@ func artifactWriter(c *cli.Context, comp artifact.Compressor, f *os.File,
 			// check if we are having correct version
 			return nil, errors.New("can not use signed artifact with version 0")
 		}
-		return awriter.NewWriterSigned(f, comp, privateKey), nil
+		return awriter.NewWriterSigned(w, comp, privateKey), nil
 	}
-	return awriter.NewWriter(f, comp), nil
+	return awriter.NewWriter(w, comp), nil
 }
 
 func makeUpdates(ctx *cli.Context) (*awriter.Updates, error) {
@@ -765,21 +767,22 @@ func writeModuleImage(ctx *cli.Context) error {
 		return err
 	}
 
-	f, err := os.Create(name + ".tmp")
-	if err != nil {
-		return cli.NewExitError(
-			"can not create artifact file: "+err.Error(),
-			errArtifactCreate,
-		)
+	var w io.Writer
+	if name == "-" {
+		w = os.Stdout
+	} else {
+		f, err := os.Create(name)
+		if err != nil {
+			return cli.NewExitError(
+				"can not create artifact file: "+err.Error(),
+				errArtifactCreate,
+			)
+		}
+		defer f.Close()
+		w = f
 	}
-	defer func() {
-		f.Close()
-		// in case of success `.tmp` suffix will be removed and below
-		// will not remove valid artifact
-		os.Remove(name + ".tmp")
-	}()
 
-	aw, err := artifactWriter(ctx, comp, f, version)
+	aw, err := artifactWriter(ctx, comp, w, version)
 	if err != nil {
 		return cli.NewExitError(err.Error(), 1)
 	}
@@ -810,6 +813,13 @@ func writeModuleImage(ctx *cli.Context) error {
 		return err
 	}
 
+	if !ctx.Bool("no-progress") {
+		ctx, cancel := context.WithCancel(context.Background())
+		go reportProgress(ctx, aw.State)
+		defer cancel()
+		aw.ProgressWriter = utils.NewProgressWriter()
+	}
+
 	err = aw.WriteArtifact(
 		&awriter.WriteArtifactArgs{
 			Format:            "mender",
@@ -828,12 +838,6 @@ func writeModuleImage(ctx *cli.Context) error {
 	if err != nil {
 		return cli.NewExitError(err.Error(), 1)
 	}
-
-	f.Close()
-	err = os.Rename(name+".tmp", name)
-	if err != nil {
-		return cli.NewExitError(err.Error(), 1)
-	}
 	return nil
 }
 
@@ -891,9 +895,18 @@ func getDeviceSnapshot(c *cli.Context) (string, error) {
 	// established (password prompt is written to /dev/tty directly,
 	// and hence impossible to detect).
 	// When user id is 0 do not bother with sudo.
-	args = append(args, "/bin/sh", "-c",
-		`'[ $(id -u) -eq 0 ] || sudo_cmd="sudo -S"; $sudo_cmd /bin/sh -c "echo `+sshInitMagic+
-			`; mender snapshot dump" | cat'`)
+	args = append(
+		args,
+		"/bin/sh",
+		"-c",
+		`'[ $(id -u) -eq 0 ] || sudo_cmd="sudo -S"`+
+			`; if which mender-snapshot 1> /dev/null`+
+			`; then $sudo_cmd /bin/sh -c "echo `+sshInitMagic+`; mender-snapshot dump" | cat`+
+			`; elif which mender 1> /dev/null`+
+			`; then $sudo_cmd /bin/sh -c "echo `+sshInitMagic+`; mender snapshot dump" | cat`+
+			`; else echo "Mender not found: Please check that Mender is installed" >&2 &&`+
+			`exit 1; fi'`,
+	)
 
 	cmd := exec.Command("ssh", args...)
 
@@ -906,7 +919,7 @@ func getDeviceSnapshot(c *cli.Context) (string, error) {
 	}
 
 	// Create tempfile for storing the snapshot
-	f, err := ioutil.TempFile("", "rootfs.tmp")
+	f, err := os.CreateTemp("", "rootfs.tmp")
 	if err != nil {
 		return "", err
 	}
@@ -964,6 +977,70 @@ func getDeviceSnapshot(c *cli.Context) (string, error) {
 
 	return filePath, err
 }
+func showProvides(c *cli.Context) (map[string]string, error) {
+	var userAtHost string
+	providesMap := make(map[string]string)
+	port := "22"
+	host := strings.TrimPrefix(c.String("file"), "ssh://")
+
+	if remotePort := strings.Split(host, ":"); len(remotePort) == 2 {
+		port = remotePort[1]
+		userAtHost = remotePort[0]
+	} else {
+		userAtHost = host
+	}
+
+	args := c.StringSlice("ssh-args")
+	// Check if port is specified explicitly with the --ssh-args flag
+	addPort := true
+	for _, arg := range args {
+		if strings.Contains(arg, "-p") {
+			addPort = false
+			break
+		}
+	}
+	if addPort {
+		args = append(args, "-p", port)
+	}
+	args = append(args, userAtHost)
+
+	providesArgs := ` 'if which mender-update 1> /dev/null` +
+		`; then mender-update show-provides` +
+		`; elif which mender 1> /dev/null` +
+		`; then mender show-provides` +
+		`; else echo "Mender not found: Please check that Mender is installed" >&2 &&` +
+		` exit 1; fi'`
+
+	args = append(
+		args,
+		"/bin/sh",
+		"-c",
+		providesArgs)
+
+	cmd := exec.Command("ssh", args...)
+
+	stdout, err := cmd.CombinedOutput()
+
+	if err != nil {
+		return nil, err
+	}
+	if len(stdout) == 0 {
+		return nil, nil
+	}
+	provides := strings.Split(string(stdout), "\n")
+
+	for _, p := range provides {
+		if p == "" || !strings.HasPrefix(p, "rootfs-image.") {
+			continue
+		}
+		info := strings.Split(p, "=")
+		if len(info) != 2 {
+			continue
+		}
+		providesMap[info[0]] = info[1]
+	}
+	return providesMap, nil
+}
 
 // Reads from src waiting for the string specified by signal, writing all other
 // output appearing at src to sink. The function returns an error if occurs
@@ -1011,6 +1088,7 @@ func recvSnapshot(dst io.Writer, src io.Reader) (int64, error) {
 	for {
 		nr, err := src.Read(buf)
 		if err == io.EOF {
+			fmt.Println()
 			break
 		} else if err != nil {
 			return written, errors.Wrap(err,
